@@ -2,7 +2,9 @@
 
 use DataFlow;
 
-$flow = DataFlow->new( [ Encoding => { from => 'iso-8859-1', to => 'utf8' } ] );
+$flow =
+  DataFlow->new(
+    procs => [ [ Encoding => { from => 'iso-8859-1', to => 'utf8' } ] ] );
 
 map {
     printf '%03d(%02x): %3s %3s' . "\n", $_, $_, chr($_),
